@@ -5,7 +5,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 sub register {
   my($self, $app, $config) = @_;
 
-  $app->routes->get('/info')->to(cb => sub { $_[0]->render_json($config) });
+  $app->routes->get('/info')->to(cb => sub { $_[0]->render(json => $config) });
 }
 
-1;
\ No newline at end of file
+1;
